package eu.ztsh.lfr.core.impl;

import eu.ztsh.lfr.core.TemperaturesService;
import eu.ztsh.lfr.model.Average;
import eu.ztsh.lfr.model.Averages;
import eu.ztsh.lfr.model.events.FileProcessedEvent;
import jakarta.annotation.Nonnull;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.event.EventListener;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class TemperaturesServiceImpl implements TemperaturesService {

    private static final Logger log = LoggerFactory.getLogger(TemperaturesServiceImpl.class);
    private Averages averages;

    @Nonnull
    @Override
    public List<Average> getTemperaturesFor(String city) {
        synchronized (this) {
            while (averages == null) {
                try {
                    wait();
                } catch (InterruptedException e) {
                    log.error("Thread was interrupted", e);
                    Thread.currentThread().interrupt();
                }
            }
            return averages.get(city);
        }
    }

    @EventListener(FileProcessedEvent.class)
    public void updateTemperatures(FileProcessedEvent event) {
        synchronized (this) {
            averages = event.averages();
            notifyAll();
        }
    }

}
